@@ -1,9 +1,9 @@
 <?php
 //============================================================+
 // File name   : tcpdf_fonts.php
-// Version     : 1.0.008
+// Version     : 1.0.010
 // Begin       : 2008-01-01
-// Last Update : 2013-07-18
+// Last Update : 2013-11-10
 // Author      : Nicola Asuni - Tecnick.com LTD - www.tecnick.com - info@tecnick.com
 // License     : GNU-LGPL v3 (http://www.gnu.org/copyleft/lesser.html)
 // -------------------------------------------------------------------
@@ -42,11 +42,17 @@
  * @class TCPDF_FONTS
  * Font methods for TCPDF library.
  * @package com.tecnick.tcpdf
- * @version 1.0.008
+ * @version 1.0.010
  * @author Nicola Asuni - info@tecnick.com
  */
 class TCPDF_FONTS {
 
+	/**
+	 * Static cache used for speed up uniord performances
+	 * @protected
+	 */
+	protected static $cache_uniord = array();
+
 	/**
 	 * Convert and add the selected TrueType or Type1 font to the fonts folder (that must be writeable).
 	 * @param $fontfile (string) Font file (full path).
@@ -607,7 +613,7 @@ class TCPDF_FONTS {
 										// combine high and low bytes
 										$c = (($i << 8) + $j);
 										$idRangeOffset = ($subHeaders[$k]['idRangeOffset'] + $j - $subHeaders[$k]['firstCode']);
-										$g = ($glyphIndexArray[$idRangeOffset] + $idDelta[$k]) % 65536;
+										$g = ($glyphIndexArray[$idRangeOffset] + $subHeaders[$k]['idDelta']) % 65536;
 										if ($g < 0) {
 											$g = 0;
 										}
@@ -1074,7 +1080,7 @@ class TCPDF_FONTS {
 								$c = (($i << 8) + $j);
 								if (isset($subsetchars[$c])) {
 									$idRangeOffset = ($subHeaders[$k]['idRangeOffset'] + $j - $subHeaders[$k]['firstCode']);
-									$g = ($glyphIndexArray[$idRangeOffset] + $idDelta[$k]) % 65536;
+									$g = ($glyphIndexArray[$idRangeOffset] + $subHeaders[$k]['idDelta']) % 65536;
 									if ($g < 0) {
 										$g = 0;
 									}
@@ -1684,6 +1690,28 @@ class TCPDF_FONTS {
 		return defined('K_PATH_FONTS') ? K_PATH_FONTS : '';
 	}
 
+	/**
+	 * Return font full path
+	 * @param $file (string) Font file name.
+	 * @param $fontdir (string) Font directory (set to false fto search on default directories)
+	 * @return string Font full path or empty string
+	 * @author Nicola Asuni
+	 * @since 6.0.025
+	 * @public static
+	 */
+	public static function getFontFullPath($file, $fontdir=false) {
+		$fontfile = '';
+		// search files on various directories
+		if (($fontdir !== false) AND @file_exists($fontdir.$file)) {
+			$fontfile = $fontdir.$file;
+		} elseif (@file_exists(self::_getfontpath().$file)) {
+			$fontfile = self::_getfontpath().$file;
+		} elseif (@file_exists($file)) {
+			$fontfile = $file;
+		}
+		return $fontfile;
+	}
+
 	/**
 	 * Converts UTF-8 characters array to array of Latin1 characters array<br>
 	 * @param $unicode (array) array containing UTF-8 unicode values
@@ -1734,6 +1762,20 @@ class TCPDF_FONTS {
 		return $outstr;
 	}
 
+	/**
+	 * Converts UTF-8 character to integer value.<br>
+	 * Uses the getUniord() method if the value is not cached.
+	 * @param $uch (string) character string to process.
+	 * @return integer Unicode value
+	 * @public static
+	 */
+	public static function uniord($uch) {
+		if (!isset(self::$cache_uniord[$uch])) {
+			self::$cache_uniord[$uch] = self::getUniord($uch);
+		}
+		return self::$cache_uniord[$uch];
+	}
+
 	/**
 	 * Converts UTF-8 character to integer value.<br>
 	 * Invalid byte sequences will be replaced with 0xFFFD (replacement character)<br>
@@ -1767,7 +1809,7 @@ class TCPDF_FONTS {
 	 * @author Nicola Asuni
 	 * @public static
 	 */
-	public static function uniord($uch) {
+	public static function getUniord($uch) {
 		if (function_exists('mb_convert_encoding')) {
 			list(, $char) = @unpack('N', mb_convert_encoding($uch, 'UCS-4BE', 'UTF-8'));
 			if ($char >= 0) {
@@ -2533,7 +2575,7 @@ class TCPDF_FONTS {
 		return $size;
 	}
 
-} // --- END OF CLASS ---
+} // END OF TCPDF_FONTS CLASS
 
 //============================================================+
 // END OF FILE
